# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_steamtv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsteammessages_steamtv.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\">\n\'CSteamTV_CreateBroadcastChannel_Request\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\"H\n(CSteamTV_CreateBroadcastChannel_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"=\n&CSteamTV_GetBroadcastChannelID_Request\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\"m\n\'CSteamTV_GetBroadcastChannelID_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"\xd4\x01\n+CSteamTV_SetBroadcastChannelProfile_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12\x10\n\x08headline\x18\x04 \x01(\t\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12\x13\n\x0b\x61vatar_hash\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\r\n\x05rules\x18\x08 \x01(\t\x12\x0e\n\x06panels\x18\t \x01(\t\".\n,CSteamTV_SetBroadcastChannelProfile_Response\"K\n+CSteamTV_GetBroadcastChannelProfile_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xe4\x01\n,CSteamTV_GetBroadcastChannelProfile_Response\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\x12\x15\n\rowner_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x10\n\x08headline\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\r\n\x05rules\x18\x08 \x01(\t\x12\x0e\n\x06panels\x18\t \x01(\t\x12\x14\n\x0cis_partnered\x18\n \x01(\x08\"\x9b\x02\n)CSteamTV_SetBroadcastChannelImage_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x44\n\nimage_type\x18\x02 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_None\x12\x13\n\x0bimage_index\x18\x03 \x01(\r\x12\x13\n\x0bimage_width\x18\x04 \x01(\r\x12\x14\n\x0cimage_height\x18\x05 \x01(\r\x12\x11\n\tfile_size\x18\x06 \x01(\r\x12\x16\n\x0e\x66ile_extension\x18\x07 \x01(\t\x12\x11\n\tfile_hash\x18\x08 \x01(\t\x12\x0c\n\x04undo\x18\t \x01(\x08\"H\n*CSteamTV_SetBroadcastChannelImage_Response\x12\x1a\n\x12replace_image_hash\x18\x01 \x01(\t\"u\n*CSteamTV_GetBroadcastChannelImages_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12)\n\x0bimage_types\x18\x02 \x03(\x0e\x32\x14.EBroadcastImageType\"\xeb\x01\n+CSteamTV_GetBroadcastChannelImages_Response\x12\x43\n\x06images\x18\x01 \x03(\x0b\x32\x33.CSteamTV_GetBroadcastChannelImages_Response.Images\x1aw\n\x06Images\x12\x44\n\nimage_type\x18\x01 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_None\x12\x12\n\nimage_path\x18\x02 \x01(\t\x12\x13\n\x0bimage_index\x18\x03 \x01(\r\"\x94\x02\n/CSteamTV_SetBroadcastChannelLinkRegions_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x45\n\x05links\x18\x02 \x03(\x0b\x32\x36.CSteamTV_SetBroadcastChannelLinkRegions_Request.Links\x1a|\n\x05Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"2\n0CSteamTV_SetBroadcastChannelLinkRegions_Response\"I\n)CSteamTV_GetBroadcastChannelLinks_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xec\x01\n*CSteamTV_GetBroadcastChannelLinks_Response\x12@\n\x05links\x18\x01 \x03(\x0b\x32\x31.CSteamTV_GetBroadcastChannelLinks_Response.Links\x1a|\n\x05Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"P\n0CSteamTV_GetBroadcastChannelBroadcasters_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xcb\x01\n1CSteamTV_GetBroadcastChannelBroadcasters_Response\x12T\n\x0c\x62roadcasters\x18\x01 \x03(\x0b\x32>.CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster\x1a@\n\x0b\x42roadcaster\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nrtmp_token\x18\x03 \x01(\t\"&\n$CSteamTV_GetFollowedChannels_Request\"\x98\x03\n\x18GetBroadcastChannelEntry\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x0f\n\x07viewers\x18\x05 \x01(\x04\x12\r\n\x05views\x18\x06 \x01(\x04\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x10\n\x08headline\x18\t \x01(\t\x12\x12\n\navatar_url\x18\n \x01(\t\x12\x1b\n\x13\x62roadcaster_steamid\x18\x0b \x01(\x06\x12\x13\n\x0bsubscribers\x18\x0c \x01(\x04\x12\x16\n\x0e\x62\x61\x63kground_url\x18\r \x01(\t\x12\x13\n\x0bis_featured\x18\x0e \x01(\x08\x12\x13\n\x0bis_disabled\x18\x0f \x01(\x08\x12\x0f\n\x07is_live\x18\x10 \x01(\x08\x12\x10\n\x08language\x18\x11 \x01(\t\x12\x0f\n\x07reports\x18\x12 \x01(\r\x12\x14\n\x0cis_partnered\x18\x13 \x01(\x08\"S\n%CSteamTV_GetFollowedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"(\n&CSteamTV_GetSubscribedChannels_Request\"U\n\'CSteamTV_GetSubscribedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"J\n*CSteamTV_GetBroadcastChannelStatus_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\x91\x02\n+CSteamTV_GetBroadcastChannelStatus_Response\x12\x0f\n\x07is_live\x18\x01 \x01(\x08\x12\x13\n\x0bis_disabled\x18\x02 \x01(\x08\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12\r\n\x05views\x18\x05 \x01(\x04\x12\x1b\n\x13\x62roadcaster_steamid\x18\x06 \x01(\x06\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x13\n\x0bsubscribers\x18\t \x01(\x04\x12\x13\n\x0bunique_name\x18\n \x01(\t\x12\x1c\n\x14\x62roadcast_session_id\x18\x0b \x01(\x04\"U\n\'CSteamTV_FollowBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04undo\x18\x02 \x01(\x08\"?\n(CSteamTV_FollowBroadcastChannel_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\"J\n*CSteamTV_SubscribeBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"D\n+CSteamTV_SubscribeBroadcastChannel_Response\x12\x15\n\ris_subscribed\x18\x01 \x01(\x08\"I\n)CSteamTV_GetBroadcastChannelClips_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\xea\x01\n\x1a\x43SteamTV_BroadcastClipInfo\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x12\x12\n\nchannel_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1b\n\x13\x62roadcaster_steamid\x18\x04 \x01(\x06\x12\x17\n\x0f\x63reator_steamid\x18\x05 \x01(\x06\x12\x19\n\x11video_description\x18\x06 \x01(\t\x12\x11\n\tlive_time\x18\x07 \x01(\r\x12\x11\n\tlength_ms\x18\x08 \x01(\r\x12\x16\n\x0ethumbnail_path\x18\t \x01(\t\"p\n*CSteamTV_GetBroadcastChannelClips_Response\x12*\n\x05\x63lips\x18\x01 \x03(\x0b\x32\x1b.CSteamTV_BroadcastClipInfo\x12\x16\n\x0ethumbnail_host\x18\x02 \x01(\t\"W\n\'CSteamTV_ReportBroadcastChannel_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0e\n\x06reason\x18\x02 \x01(\t\"*\n(CSteamTV_ReportBroadcastChannel_Response\"O\n/CSteamTV_GetBroadcastChannelInteraction_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"^\n0CSteamTV_GetBroadcastChannelInteraction_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\x12\x15\n\ris_subscribed\x18\x02 \x01(\x08\"\x7f\n\x19\x43SteamTV_GetGames_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x44\n\talgorithm\x18\x02 \x01(\x0e\x32\x13.EGetGamesAlgorithm:\x1ck_EGetGamesAlgorithm_Default\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xb5\x01\n\rCSteamTV_Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12+\n\x08\x63hannels\x18\x05 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\x14\n\x0crelease_date\x18\x06 \x01(\t\x12\x11\n\tdeveloper\x18\x07 \x01(\t\x12\x11\n\tpublisher\x18\x08 \x01(\t\"=\n\x1a\x43SteamTV_GetGames_Response\x12\x1f\n\x07results\x18\x01 \x03(\x0b\x32\x0e.CSteamTV_Game\"\x88\x01\n\x1c\x43SteamTV_GetChannels_Request\x12J\n\talgorithm\x18\x01 \x01(\x0e\x32\x16.EGetChannelsAlgorithm:\x1fk_EGetChannelsAlgorithm_Default\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"K\n\x1d\x43SteamTV_GetChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"\x87\x01\n\x1b\x43SteamTV_AddChatBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04undo\x18\x05 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddChatBan_Response\"<\n\x1c\x43SteamTV_GetChatBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"z\n\x10\x43SteamTV_ChatBan\x12\x16\n\x0eissuer_steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\t\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"C\n\x1d\x43SteamTV_GetChatBans_Response\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.CSteamTV_ChatBan\"j\n!CSteamTV_AddChatModerator_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x19\n\x11moderator_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"$\n\"CSteamTV_AddChatModerator_Response\"B\n\"CSteamTV_GetChatModerators_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"7\n\x16\x43SteamTV_ChatModerator\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n#CSteamTV_GetChatModerators_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CSteamTV_ChatModerator\"W\n\x1b\x43SteamTV_AddWordBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04word\x18\x02 \x01(\t\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddWordBan_Response\"<\n\x1c\x43SteamTV_GetWordBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"0\n\x1d\x43SteamTV_GetWordBans_Response\x12\x0f\n\x07results\x18\x01 \x03(\t\"9\n\x19\x43SteamTV_JoinChat_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"a\n\x1a\x43SteamTV_JoinChat_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x02 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x03 \x03(\x04\"\'\n\x17\x43SteamTV_Search_Request\x12\x0c\n\x04term\x18\x01 \x01(\t\"F\n\x18\x43SteamTV_Search_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\")\n\'CSteamTV_GetSteamTVUserSettings_Request\"g\n(CSteamTV_GetSteamTVUserSettings_Response\x12\x19\n\x11stream_live_email\x18\x01 \x01(\x08\x12 \n\x18stream_live_notification\x18\x02 \x01(\x08\"f\n\'CSteamTV_SetSteamTVUserSettings_Request\x12\x19\n\x11stream_live_email\x18\x01 \x01(\x08\x12 \n\x18stream_live_notification\x18\x02 \x01(\x08\"*\n(CSteamTV_SetSteamTVUserSettings_Response\")\n\'CSteamTV_GetMyBroadcastChannels_Request\"V\n(CSteamTV_GetMyBroadcastChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"&\n$CSteamTV_GetHomePageContents_Request\"S\n\"CSteamTV_HomePageTemplate_Takeover\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"s\n$CSteamTV_HomePageTemplate_SingleGame\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\"_\n\rGameListEntry\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12,\n\tbroadcast\x18\x03 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\"T\n\"CSteamTV_HomePageTemplate_GameList\x12\x1f\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0e.GameListEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_QuickExplore\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_ConveyorBelt\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"z\n$CSteamTV_HomePageTemplate_WatchParty\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"b\n#CSteamTV_HomePageTemplate_Developer\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"0\n\x1f\x43SteamTV_HomePageTemplate_Event\x12\r\n\x05title\x18\x01 \x01(\t\"\xc2\x04\n\x1b\x43SteamTV_HomePageContentRow\x12R\n\rtemplate_type\x18\x01 \x01(\x0e\x32\x18.ESteamTVContentTemplate:!k_ESteamTVContentTemplate_Invalid\x12\x35\n\x08takeover\x18\x02 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_Takeover\x12:\n\x0bsingle_game\x18\x03 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_SingleGame\x12\x36\n\tgame_list\x18\x04 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_GameList\x12>\n\rquick_explore\x18\x05 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_QuickExplore\x12>\n\rconveyor_belt\x18\x06 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_ConveyorBelt\x12:\n\x0bwatch_party\x18\x07 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_WatchParty\x12\x37\n\tdeveloper\x18\x08 \x01(\x0b\x32$.CSteamTV_HomePageTemplate_Developer\x12/\n\x05\x65vent\x18\t \x01(\x0b\x32 .CSteamTV_HomePageTemplate_Event\"S\n%CSteamTV_GetHomePageContents_Response\x12*\n\x04rows\x18\x01 \x03(\x0b\x32\x1c.CSteamTV_HomePageContentRow\"M\n!CSteamTV_AppCheer_SingleCheerType\x12\x12\n\ncheer_type\x18\x01 \x01(\r\x12\x14\n\x0c\x63heer_amount\x18\x02 \x01(\r\"x\n\x19\x43SteamTV_AppCheer_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x17\n\x0f\x63heer_target_id\x18\x02 \x01(\x06\x12\x32\n\x06\x63heers\x18\x03 \x03(\x0b\x32\".CSteamTV_AppCheer_SingleCheerType\":\n\x1a\x43SteamTV_AppCheer_Response\x12\x1c\n\x14\x61ggregation_delay_ms\x18\x01 \x01(\r*\x8a\x02\n\x13\x45\x42roadcastImageType\x12\x1e\n\x1ak_EBroadcastImageType_None\x10\x00\x12!\n\x1dk_EBroadcastImageType_Offline\x10\x01\x12!\n\x1dk_EBroadcastImageType_Standby\x10\x02\x12 \n\x1ck_EBroadcastImageType_Avatar\x10\x03\x12!\n\x1dk_EBroadcastImageType_Summary\x10\x04\x12$\n k_EBroadcastImageType_Background\x10\x05\x12\"\n\x1ek_EBroadcastImageType_Emoticon\x10\x06*\x80\x01\n\x12\x45GetGamesAlgorithm\x12 \n\x1ck_EGetGamesAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetGamesAlgorithm_MostPlayed\x10\x02\x12#\n\x1fk_EGetGamesAlgorithm_PopularNew\x10\x03*\xd5\x01\n\x15\x45GetChannelsAlgorithm\x12#\n\x1fk_EGetChannelsAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetChannelsAlgorithm_Friends\x10\x02\x12$\n k_EGetChannelsAlgorithm_Featured\x10\x03\x12%\n!k_EGetChannelsAlgorithm_Developer\x10\x04\x12%\n!k_EGetChannelsAlgorithm_Following\x10\x05*\x8a\x03\n\x17\x45SteamTVContentTemplate\x12%\n!k_ESteamTVContentTemplate_Invalid\x10\x00\x12&\n\"k_ESteamTVContentTemplate_Takeover\x10\x01\x12(\n$k_ESteamTVContentTemplate_SingleGame\x10\x02\x12&\n\"k_ESteamTVContentTemplate_GameList\x10\x03\x12*\n&k_ESteamTVContentTemplate_QuickExplore\x10\x04\x12*\n&k_ESteamTVContentTemplate_ConveyorBelt\x10\x05\x12(\n$k_ESteamTVContentTemplate_WatchParty\x10\x06\x12\'\n#k_ESteamTVContentTemplate_Developer\x10\x07\x12#\n\x1fk_ESteamTVContentTemplate_Event\x10\x08\x32\xea\x19\n\x07SteamTV\x12m\n\x16\x43reateBroadcastChannel\x12(.CSteamTV_CreateBroadcastChannel_Request\x1a).CSteamTV_CreateBroadcastChannel_Response\x12j\n\x15GetBroadcastChannelID\x12\'.CSteamTV_GetBroadcastChannelID_Request\x1a(.CSteamTV_GetBroadcastChannelID_Response\x12y\n\x1aSetBroadcastChannelProfile\x12,.CSteamTV_SetBroadcastChannelProfile_Request\x1a-.CSteamTV_SetBroadcastChannelProfile_Response\x12y\n\x1aGetBroadcastChannelProfile\x12,.CSteamTV_GetBroadcastChannelProfile_Request\x1a-.CSteamTV_GetBroadcastChannelProfile_Response\x12s\n\x18SetBroadcastChannelImage\x12*.CSteamTV_SetBroadcastChannelImage_Request\x1a+.CSteamTV_SetBroadcastChannelImage_Response\x12v\n\x19GetBroadcastChannelImages\x12+.CSteamTV_GetBroadcastChannelImages_Request\x1a,.CSteamTV_GetBroadcastChannelImages_Response\x12\x85\x01\n\x1eSetBroadcastChannelLinkRegions\x12\x30.CSteamTV_SetBroadcastChannelLinkRegions_Request\x1a\x31.CSteamTV_SetBroadcastChannelLinkRegions_Response\x12s\n\x18GetBroadcastChannelLinks\x12*.CSteamTV_GetBroadcastChannelLinks_Request\x1a+.CSteamTV_GetBroadcastChannelLinks_Response\x12\x88\x01\n\x1fGetBroadcastChannelBroadcasters\x12\x31.CSteamTV_GetBroadcastChannelBroadcasters_Request\x1a\x32.CSteamTV_GetBroadcastChannelBroadcasters_Response\x12\x64\n\x13GetFollowedChannels\x12%.CSteamTV_GetFollowedChannels_Request\x1a&.CSteamTV_GetFollowedChannels_Response\x12j\n\x15GetSubscribedChannels\x12\'.CSteamTV_GetSubscribedChannels_Request\x1a(.CSteamTV_GetSubscribedChannels_Response\x12v\n\x19GetBroadcastChannelStatus\x12+.CSteamTV_GetBroadcastChannelStatus_Request\x1a,.CSteamTV_GetBroadcastChannelStatus_Response\x12m\n\x16\x46ollowBroadcastChannel\x12(.CSteamTV_FollowBroadcastChannel_Request\x1a).CSteamTV_FollowBroadcastChannel_Response\x12v\n\x19SubscribeBroadcastChannel\x12+.CSteamTV_SubscribeBroadcastChannel_Request\x1a,.CSteamTV_SubscribeBroadcastChannel_Response\x12s\n\x18GetBroadcastChannelClips\x12*.CSteamTV_GetBroadcastChannelClips_Request\x1a+.CSteamTV_GetBroadcastChannelClips_Response\x12m\n\x16ReportBroadcastChannel\x12(.CSteamTV_ReportBroadcastChannel_Request\x1a).CSteamTV_ReportBroadcastChannel_Response\x12\x85\x01\n\x1eGetBroadcastChannelInteraction\x12\x30.CSteamTV_GetBroadcastChannelInteraction_Request\x1a\x31.CSteamTV_GetBroadcastChannelInteraction_Response\x12\x43\n\x08GetGames\x12\x1a.CSteamTV_GetGames_Request\x1a\x1b.CSteamTV_GetGames_Response\x12L\n\x0bGetChannels\x12\x1d.CSteamTV_GetChannels_Request\x1a\x1e.CSteamTV_GetChannels_Response\x12I\n\nAddChatBan\x12\x1c.CSteamTV_AddChatBan_Request\x1a\x1d.CSteamTV_AddChatBan_Response\x12L\n\x0bGetChatBans\x12\x1d.CSteamTV_GetChatBans_Request\x1a\x1e.CSteamTV_GetChatBans_Response\x12[\n\x10\x41\x64\x64\x43hatModerator\x12\".CSteamTV_AddChatModerator_Request\x1a#.CSteamTV_AddChatModerator_Response\x12^\n\x11GetChatModerators\x12#.CSteamTV_GetChatModerators_Request\x1a$.CSteamTV_GetChatModerators_Response\x12I\n\nAddWordBan\x12\x1c.CSteamTV_AddWordBan_Request\x1a\x1d.CSteamTV_AddWordBan_Response\x12L\n\x0bGetWordBans\x12\x1d.CSteamTV_GetWordBans_Request\x1a\x1e.CSteamTV_GetWordBans_Response\x12\x43\n\x08JoinChat\x12\x1a.CSteamTV_JoinChat_Request\x1a\x1b.CSteamTV_JoinChat_Response\x12=\n\x06Search\x12\x18.CSteamTV_Search_Request\x1a\x19.CSteamTV_Search_Response\x12m\n\x16GetSteamTVUserSettings\x12(.CSteamTV_GetSteamTVUserSettings_Request\x1a).CSteamTV_GetSteamTVUserSettings_Response\x12m\n\x16SetSteamTVUserSettings\x12(.CSteamTV_SetSteamTVUserSettings_Request\x1a).CSteamTV_SetSteamTVUserSettings_Response\x12m\n\x16GetMyBroadcastChannels\x12(.CSteamTV_GetMyBroadcastChannels_Request\x1a).CSteamTV_GetMyBroadcastChannels_Response\x12\x64\n\x13GetHomePageContents\x12%.CSteamTV_GetHomePageContents_Request\x1a&.CSteamTV_GetHomePageContents_Response\x12\x43\n\x08\x41ppCheer\x12\x1a.CSteamTV_AppCheer_Request\x1a\x1b.CSteamTV_AppCheer_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_steamtv_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EBROADCASTIMAGETYPE._serialized_start=8810
  _EBROADCASTIMAGETYPE._serialized_end=9076
  _EGETGAMESALGORITHM._serialized_start=9079
  _EGETGAMESALGORITHM._serialized_end=9207
  _EGETCHANNELSALGORITHM._serialized_start=9210
  _EGETCHANNELSALGORITHM._serialized_end=9423
  _ESTEAMTVCONTENTTEMPLATE._serialized_start=9426
  _ESTEAMTVCONTENTTEMPLATE._serialized_end=9820
  _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST._serialized_start=91
  _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST._serialized_end=153
  _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE._serialized_start=155
  _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE._serialized_end=227
  _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST._serialized_start=229
  _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST._serialized_end=290
  _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE._serialized_start=292
  _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE._serialized_end=401
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST._serialized_start=404
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST._serialized_end=616
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE._serialized_start=618
  _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE._serialized_end=664
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST._serialized_start=666
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST._serialized_end=741
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE._serialized_start=744
  _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE._serialized_end=972
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST._serialized_start=975
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST._serialized_end=1258
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE._serialized_start=1260
  _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE._serialized_end=1332
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST._serialized_start=1334
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST._serialized_end=1451
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE._serialized_start=1454
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE._serialized_end=1689
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES._serialized_start=1570
  _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES._serialized_end=1689
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST._serialized_start=1692
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST._serialized_end=1968
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS._serialized_start=1844
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS._serialized_end=1968
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE._serialized_start=1970
  _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE._serialized_end=2020
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST._serialized_start=2022
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST._serialized_end=2095
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE._serialized_start=2098
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE._serialized_end=2334
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS._serialized_start=1844
  _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS._serialized_end=1968
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST._serialized_start=2336
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST._serialized_end=2416
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE._serialized_start=2419
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE._serialized_end=2622
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER._serialized_start=2558
  _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER._serialized_end=2622
  _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST._serialized_start=2624
  _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST._serialized_end=2662
  _GETBROADCASTCHANNELENTRY._serialized_start=2665
  _GETBROADCASTCHANNELENTRY._serialized_end=3073
  _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE._serialized_start=3075
  _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE._serialized_end=3158
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST._serialized_start=3160
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST._serialized_end=3200
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE._serialized_start=3202
  _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE._serialized_end=3287
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST._serialized_start=3289
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST._serialized_end=3363
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE._serialized_start=3366
  _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE._serialized_end=3639
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST._serialized_start=3641
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST._serialized_end=3726
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE._serialized_start=3728
  _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE._serialized_end=3791
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST._serialized_start=3793
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST._serialized_end=3867
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE._serialized_start=3869
  _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE._serialized_end=3937
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST._serialized_start=3939
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST._serialized_end=4012
  _CSTEAMTV_BROADCASTCLIPINFO._serialized_start=4015
  _CSTEAMTV_BROADCASTCLIPINFO._serialized_end=4249
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE._serialized_start=4251
  _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE._serialized_end=4363
  _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST._serialized_start=4365
  _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST._serialized_end=4452
  _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE._serialized_start=4454
  _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE._serialized_end=4496
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST._serialized_start=4498
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST._serialized_end=4577
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE._serialized_start=4579
  _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE._serialized_end=4673
  _CSTEAMTV_GETGAMES_REQUEST._serialized_start=4675
  _CSTEAMTV_GETGAMES_REQUEST._serialized_end=4802
  _CSTEAMTV_GAME._serialized_start=4805
  _CSTEAMTV_GAME._serialized_end=4986
  _CSTEAMTV_GETGAMES_RESPONSE._serialized_start=4988
  _CSTEAMTV_GETGAMES_RESPONSE._serialized_end=5049
  _CSTEAMTV_GETCHANNELS_REQUEST._serialized_start=5052
  _CSTEAMTV_GETCHANNELS_REQUEST._serialized_end=5188
  _CSTEAMTV_GETCHANNELS_RESPONSE._serialized_start=5190
  _CSTEAMTV_GETCHANNELS_RESPONSE._serialized_end=5265
  _CSTEAMTV_ADDCHATBAN_REQUEST._serialized_start=5268
  _CSTEAMTV_ADDCHATBAN_REQUEST._serialized_end=5403
  _CSTEAMTV_ADDCHATBAN_RESPONSE._serialized_start=5405
  _CSTEAMTV_ADDCHATBAN_RESPONSE._serialized_end=5435
  _CSTEAMTV_GETCHATBANS_REQUEST._serialized_start=5437
  _CSTEAMTV_GETCHATBANS_REQUEST._serialized_end=5497
  _CSTEAMTV_CHATBAN._serialized_start=5499
  _CSTEAMTV_CHATBAN._serialized_end=5621
  _CSTEAMTV_GETCHATBANS_RESPONSE._serialized_start=5623
  _CSTEAMTV_GETCHATBANS_RESPONSE._serialized_end=5690
  _CSTEAMTV_ADDCHATMODERATOR_REQUEST._serialized_start=5692
  _CSTEAMTV_ADDCHATMODERATOR_REQUEST._serialized_end=5798
  _CSTEAMTV_ADDCHATMODERATOR_RESPONSE._serialized_start=5800
  _CSTEAMTV_ADDCHATMODERATOR_RESPONSE._serialized_end=5836
  _CSTEAMTV_GETCHATMODERATORS_REQUEST._serialized_start=5838
  _CSTEAMTV_GETCHATMODERATORS_REQUEST._serialized_end=5904
  _CSTEAMTV_CHATMODERATOR._serialized_start=5906
  _CSTEAMTV_CHATMODERATOR._serialized_end=5961
  _CSTEAMTV_GETCHATMODERATORS_RESPONSE._serialized_start=5963
  _CSTEAMTV_GETCHATMODERATORS_RESPONSE._serialized_end=6042
  _CSTEAMTV_ADDWORDBAN_REQUEST._serialized_start=6044
  _CSTEAMTV_ADDWORDBAN_REQUEST._serialized_end=6131
  _CSTEAMTV_ADDWORDBAN_RESPONSE._serialized_start=6133
  _CSTEAMTV_ADDWORDBAN_RESPONSE._serialized_end=6163
  _CSTEAMTV_GETWORDBANS_REQUEST._serialized_start=6165
  _CSTEAMTV_GETWORDBANS_REQUEST._serialized_end=6225
  _CSTEAMTV_GETWORDBANS_RESPONSE._serialized_start=6227
  _CSTEAMTV_GETWORDBANS_RESPONSE._serialized_end=6275
  _CSTEAMTV_JOINCHAT_REQUEST._serialized_start=6277
  _CSTEAMTV_JOINCHAT_REQUEST._serialized_end=6334
  _CSTEAMTV_JOINCHAT_RESPONSE._serialized_start=6336
  _CSTEAMTV_JOINCHAT_RESPONSE._serialized_end=6433
  _CSTEAMTV_SEARCH_REQUEST._serialized_start=6435
  _CSTEAMTV_SEARCH_REQUEST._serialized_end=6474
  _CSTEAMTV_SEARCH_RESPONSE._serialized_start=6476
  _CSTEAMTV_SEARCH_RESPONSE._serialized_end=6546
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST._serialized_start=6548
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST._serialized_end=6589
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE._serialized_start=6591
  _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE._serialized_end=6694
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST._serialized_start=6696
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST._serialized_end=6798
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE._serialized_start=6800
  _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE._serialized_end=6842
  _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST._serialized_start=6844
  _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST._serialized_end=6885
  _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE._serialized_start=6887
  _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE._serialized_end=6973
  _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST._serialized_start=6975
  _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST._serialized_end=7013
  _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER._serialized_start=7015
  _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER._serialized_end=7098
  _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME._serialized_start=7100
  _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME._serialized_end=7215
  _GAMELISTENTRY._serialized_start=7217
  _GAMELISTENTRY._serialized_end=7312
  _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST._serialized_start=7314
  _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST._serialized_end=7398
  _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE._serialized_start=7400
  _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE._serialized_end=7502
  _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT._serialized_start=7504
  _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT._serialized_end=7606
  _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY._serialized_start=7608
  _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY._serialized_end=7730
  _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER._serialized_start=7732
  _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER._serialized_end=7830
  _CSTEAMTV_HOMEPAGETEMPLATE_EVENT._serialized_start=7832
  _CSTEAMTV_HOMEPAGETEMPLATE_EVENT._serialized_end=7880
  _CSTEAMTV_HOMEPAGECONTENTROW._serialized_start=7883
  _CSTEAMTV_HOMEPAGECONTENTROW._serialized_end=8461
  _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE._serialized_start=8463
  _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE._serialized_end=8546
  _CSTEAMTV_APPCHEER_SINGLECHEERTYPE._serialized_start=8548
  _CSTEAMTV_APPCHEER_SINGLECHEERTYPE._serialized_end=8625
  _CSTEAMTV_APPCHEER_REQUEST._serialized_start=8627
  _CSTEAMTV_APPCHEER_REQUEST._serialized_end=8747
  _CSTEAMTV_APPCHEER_RESPONSE._serialized_start=8749
  _CSTEAMTV_APPCHEER_RESPONSE._serialized_end=8807
  _STEAMTV._serialized_start=9823
  _STEAMTV._serialized_end=13129
_builder.BuildServices(DESCRIPTOR, 'steammessages_steamtv_pb2', globals())
# @@protoc_insertion_point(module_scope)




from steam.enums import EResult

class SteamError(Exception):
    """ General error that also carries EResult code """
    def __init__(self, message, eresult=EResult.Fail):
        Exception.__init__(self, message, eresult)
        self.message = message
        self.eresult = EResult(eresult)  #: :class:`.EResult`

    def __str__(self):
        return "(%s) %s" % (self.eresult, self.message)

class ManifestError(SteamError):
    """
    Raised when there a problem getting a manifest by :class:`CDNClient`
    Encapsulates original exception in :attr:`.error` and includes manifest details
    """
    def __init__(self, message, app_id, depot_id, manifest_gid, error=None):
        self.message = message
        self.app_id = app_id
        self.depot_id = depot_id
        self.manifest_gid = manifest_gid
        self.error = error

        if isinstance(error, SteamError):
            self.eresult = error.eresult
        else:
            self.eresult = EResult.Fail

    def __repr__(self):
        return "%s(%s, app=%s, depot=%s, manifest=%s, error=%s)" % (
            self.__class__.__name__,
            repr(self.message),
            self.app_id,
            self.depot_id,
            self.manifest_gid,
            repr(self.error),
        )

    def __str__(self):
        return "(%s) %s (app=%s depot=%s manifest=%s)" % (
            self.eresult,
            self.message,
            self.app_id,
            self.depot_id,
            self.manifest_gid,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_useraccount.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_useraccount.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"P\n8CUserAccount_GetAvailableValveDiscountPromotions_Request\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\"\x85\x04\n9CUserAccount_GetAvailableValveDiscountPromotions_Response\x12l\n\npromotions\x18\x01 \x03(\x0b\x32X.CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails\x1a\xd9\x02\n\x1dValveDiscountPromotionDetails\x12\x13\n\x0bpromotionid\x18\x01 \x01(\r\x12\x1d\n\x15promotion_description\x18\x02 \x01(\t\x12\x1b\n\x13minimum_cart_amount\x18\x03 \x01(\x03\x12\'\n\x1fminimum_cart_amount_for_display\x18\x04 \x01(\x03\x12\x17\n\x0f\x64iscount_amount\x18\x05 \x01(\x03\x12\x15\n\rcurrency_code\x18\x06 \x01(\x05\x12\x1b\n\x13\x61vailable_use_count\x18\x07 \x01(\x05\x12!\n\x19promotional_discount_type\x18\x08 \x01(\x05\x12\x19\n\x11loyalty_reward_id\x18\t \x01(\x05\x12\x1c\n\x14localized_name_token\x18\n \x01(\t\x12\x15\n\rmax_use_count\x18\x0b \x01(\x05\"\x8a\x01\n+CUserAccount_GetClientWalletDetails_Request\x12\x1e\n\x16include_balance_in_usd\x18\x01 \x01(\x08\x12\x18\n\rwallet_region\x18\x02 \x01(\x05:\x01\x31\x12!\n\x19include_formatted_balance\x18\x03 \x01(\x08\"\xb5\x04\n&CUserAccount_GetWalletDetails_Response\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x19\n\x11user_country_code\x18\x02 \x01(\t\x12\x1b\n\x13wallet_country_code\x18\x03 \x01(\t\x12\x14\n\x0cwallet_state\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x05 \x01(\x03\x12\x17\n\x0f\x64\x65layed_balance\x18\x06 \x01(\x03\x12\x15\n\rcurrency_code\x18\x07 \x01(\x05\x12\x1c\n\x14time_most_recent_txn\x18\x08 \x01(\r\x12\x19\n\x11most_recent_txnid\x18\t \x01(\x04\x12\x16\n\x0e\x62\x61lance_in_usd\x18\n \x01(\x03\x12\x1e\n\x16\x64\x65layed_balance_in_usd\x18\x0b \x01(\x03\x12#\n\x1bhas_wallet_in_other_regions\x18\x0c \x01(\x08\x12\x15\n\rother_regions\x18\r \x03(\x05\x12\x19\n\x11\x66ormatted_balance\x18\x0e \x01(\t\x12!\n\x19\x66ormatted_delayed_balance\x18\x0f \x01(\t\x12*\n\"delayed_balance_available_min_time\x18\x10 \x01(\x05\x12*\n\"delayed_balance_available_max_time\x18\x11 \x01(\x05\x12%\n\x1d\x64\x65layed_balance_newest_source\x18\x12 \x01(\x05\"+\n)CUserAccount_GetAccountLinkStatus_Request\"}\n*CUserAccount_GetAccountLinkStatus_Response\x12\x0c\n\x04pwid\x18\x01 \x01(\r\x12\x1d\n\x15identity_verification\x18\x02 \x01(\r\x12\"\n\x1aperformed_age_verification\x18\x03 \x01(\x08\"9\n(CUserAccount_CancelLicenseForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"+\n)CUserAccount_CancelLicenseForApp_Response\"6\n#CUserAccount_GetUserCountry_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"7\n$CUserAccount_GetUserCountry_Response\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\"r\n,CUserAccount_CreateFriendInviteToken_Request\x12\x14\n\x0cinvite_limit\x18\x01 \x01(\r\x12\x17\n\x0finvite_duration\x18\x02 \x01(\r\x12\x13\n\x0binvite_note\x18\x03 \x01(\t\"\x99\x01\n-CUserAccount_CreateFriendInviteToken_Response\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\x12\x14\n\x0cinvite_limit\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\x12\x14\n\x0ctime_created\x18\x04 \x01(\x07\x12\r\n\x05valid\x18\x05 \x01(\x08\",\n*CUserAccount_GetFriendInviteTokens_Request\"m\n+CUserAccount_GetFriendInviteTokens_Response\x12>\n\x06tokens\x18\x01 \x03(\x0b\x32..CUserAccount_CreateFriendInviteToken_Response\"S\n*CUserAccount_ViewFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"f\n+CUserAccount_ViewFriendInviteToken_Response\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\"U\n,CUserAccount_RedeemFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"/\n-CUserAccount_RedeemFriendInviteToken_Response\"D\n,CUserAccount_RevokeFriendInviteToken_Request\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\"/\n-CUserAccount_RevokeFriendInviteToken_Response\">\n\'CUserAccount_RegisterCompatTool_Request\x12\x13\n\x0b\x63ompat_tool\x18\x01 \x01(\r\"*\n(CUserAccount_RegisterCompatTool_Response\"w\n.CEmbeddedClient_AuthorizeCurrentDevice_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_info\x18\x03 \x01(\t\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"`\n\x15\x43\x45mbeddedClient_Token\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x63lient_token\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"a\n(CEmbeddedClient_AuthorizeDevice_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12%\n\x05token\x18\x02 \x01(\x0b\x32\x16.CEmbeddedClient_Token2\x9c\n\n\x0bUserAccount\x12\x9c\x01\n#GetAvailableValveDiscountPromotions\x12\x39.CUserAccount_GetAvailableValveDiscountPromotions_Request\x1a:.CUserAccount_GetAvailableValveDiscountPromotions_Response\x12o\n\x16GetClientWalletDetails\x12,.CUserAccount_GetClientWalletDetails_Request\x1a\'.CUserAccount_GetWalletDetails_Response\x12o\n\x14GetAccountLinkStatus\x12*.CUserAccount_GetAccountLinkStatus_Request\x1a+.CUserAccount_GetAccountLinkStatus_Response\x12l\n\x13\x43\x61ncelLicenseForApp\x12).CUserAccount_CancelLicenseForApp_Request\x1a*.CUserAccount_CancelLicenseForApp_Response\x12]\n\x0eGetUserCountry\x12$.CUserAccount_GetUserCountry_Request\x1a%.CUserAccount_GetUserCountry_Response\x12x\n\x17\x43reateFriendInviteToken\x12-.CUserAccount_CreateFriendInviteToken_Request\x1a..CUserAccount_CreateFriendInviteToken_Response\x12r\n\x15GetFriendInviteTokens\x12+.CUserAccount_GetFriendInviteTokens_Request\x1a,.CUserAccount_GetFriendInviteTokens_Response\x12r\n\x15ViewFriendInviteToken\x12+.CUserAccount_ViewFriendInviteToken_Request\x1a,.CUserAccount_ViewFriendInviteToken_Response\x12x\n\x17RedeemFriendInviteToken\x12-.CUserAccount_RedeemFriendInviteToken_Request\x1a..CUserAccount_RedeemFriendInviteToken_Response\x12x\n\x17RevokeFriendInviteToken\x12-.CUserAccount_RevokeFriendInviteToken_Request\x1a..CUserAccount_RevokeFriendInviteToken_Response\x12i\n\x12RegisterCompatTool\x12(.CUserAccount_RegisterCompatTool_Request\x1a).CUserAccount_RegisterCompatTool_Response2\x86\x01\n\x0e\x45mbeddedClient\x12t\n\x16\x41uthorizeCurrentDevice\x12/.CEmbeddedClient_AuthorizeCurrentDevice_Request\x1a).CEmbeddedClient_AuthorizeDevice_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_useraccount_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST._serialized_start=95
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST._serialized_end=175
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE._serialized_start=178
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE._serialized_end=695
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS._serialized_start=350
  _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS._serialized_end=695
  _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST._serialized_start=698
  _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST._serialized_end=836
  _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE._serialized_start=839
  _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE._serialized_end=1404
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST._serialized_start=1406
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST._serialized_end=1449
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE._serialized_start=1451
  _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE._serialized_end=1576
  _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST._serialized_start=1578
  _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST._serialized_end=1635
  _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE._serialized_start=1637
  _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE._serialized_end=1680
  _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST._serialized_start=1682
  _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST._serialized_end=1736
  _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE._serialized_start=1738
  _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE._serialized_end=1793
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST._serialized_start=1795
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST._serialized_end=1909
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE._serialized_start=1912
  _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE._serialized_end=2065
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST._serialized_start=2067
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST._serialized_end=2111
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE._serialized_start=2113
  _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE._serialized_end=2222
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST._serialized_start=2224
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST._serialized_end=2307
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE._serialized_start=2309
  _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE._serialized_end=2411
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST._serialized_start=2413
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST._serialized_end=2498
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE._serialized_start=2500
  _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE._serialized_end=2547
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST._serialized_start=2549
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST._serialized_end=2617
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE._serialized_start=2619
  _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE._serialized_end=2666
  _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST._serialized_start=2668
  _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST._serialized_end=2730
  _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE._serialized_start=2732
  _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE._serialized_end=2774
  _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST._serialized_start=2776
  _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST._serialized_end=2895
  _CEMBEDDEDCLIENT_TOKEN._serialized_start=2897
  _CEMBEDDEDCLIENT_TOKEN._serialized_end=2993
  _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE._serialized_start=2995
  _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE._serialized_end=3092
  _USERACCOUNT._serialized_start=3095
  _USERACCOUNT._serialized_end=4403
  _EMBEDDEDCLIENT._serialized_start=4406
  _EMBEDDEDCLIENT._serialized_end=4540
_builder.BuildServices(DESCRIPTOR, 'steammessages_useraccount_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_hiddevices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esteammessages_hiddevices.proto\"\xce\x04\n\x0e\x43HIDDeviceInfo\x12=\n\x08location\x18\x01 \x01(\x0e\x32\x13.EHIDDeviceLocation:\x16k_EDeviceLocationLocal\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tvendor_id\x18\x03 \x01(\r\x12\x12\n\nproduct_id\x18\x04 \x01(\r\x12\x15\n\rserial_number\x18\x05 \x01(\t\x12\x16\n\x0erelease_number\x18\x06 \x01(\r\x12\x1b\n\x13manufacturer_string\x18\x07 \x01(\t\x12\x16\n\x0eproduct_string\x18\x08 \x01(\t\x12\x12\n\nusage_page\x18\t \x01(\r\x12\r\n\x05usage\x18\n \x01(\r\x12\x1c\n\x10interface_number\x18\x0b \x01(\x05:\x02-1\x12\x12\n\x06ostype\x18\x0c \x01(\x05:\x02-1\x12\x1a\n\x12is_generic_gamepad\x18\r \x01(\x08\x12\x1b\n\x13is_generic_joystick\x18\x0e \x01(\x08\x12\x11\n\tcaps_bits\x18\x0f \x01(\r\x12\x12\n\nsession_id\x18\x10 \x01(\r\x12#\n\x18\x65\x43ontrollerType_OBSOLETE\x18\x11 \x01(\r:\x01\x30\x12(\n\x19is_xinput_device_OBSOLETE\x18\x12 \x01(\x08:\x05\x66\x61lse\x12*\n\"session_remote_play_together_appid\x18\x13 \x01(\r\x12 \n\x11is_steamvr_device\x18\x14 \x01(\x08:\x05\x66\x61lse\x12\x12\n\ncaps_bits2\x18\x15 \x01(\r\"w\n\x15\x43HIDDeviceInputReport\x12\x13\n\x0b\x66ull_report\x18\x01 \x01(\x0c\x12\x14\n\x0c\x64\x65lta_report\x18\x02 \x01(\x0c\x12\x19\n\x11\x64\x65lta_report_size\x18\x03 \x01(\r\x12\x18\n\x10\x64\x65lta_report_crc\x18\x04 \x01(\r\"\xe2\x0c\n\x13\x43HIDMessageToRemote\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x36\n\x0b\x64\x65vice_open\x18\x02 \x01(\x0b\x32\x1f.CHIDMessageToRemote.DeviceOpenH\x00\x12\x38\n\x0c\x64\x65vice_close\x18\x03 \x01(\x0b\x32 .CHIDMessageToRemote.DeviceCloseH\x00\x12\x38\n\x0c\x64\x65vice_write\x18\x04 \x01(\x0b\x32 .CHIDMessageToRemote.DeviceWriteH\x00\x12\x36\n\x0b\x64\x65vice_read\x18\x05 \x01(\x0b\x32\x1f.CHIDMessageToRemote.DeviceReadH\x00\x12R\n\x1a\x64\x65vice_send_feature_report\x18\x06 \x01(\x0b\x32,.CHIDMessageToRemote.DeviceSendFeatureReportH\x00\x12P\n\x19\x64\x65vice_get_feature_report\x18\x07 \x01(\x0b\x32+.CHIDMessageToRemote.DeviceGetFeatureReportH\x00\x12N\n\x18\x64\x65vice_get_vendor_string\x18\x08 \x01(\x0b\x32*.CHIDMessageToRemote.DeviceGetVendorStringH\x00\x12P\n\x19\x64\x65vice_get_product_string\x18\t \x01(\x0b\x32+.CHIDMessageToRemote.DeviceGetProductStringH\x00\x12[\n\x1f\x64\x65vice_get_serial_number_string\x18\n \x01(\x0b\x32\x30.CHIDMessageToRemote.DeviceGetSerialNumberStringH\x00\x12R\n\x1a\x64\x65vice_start_input_reports\x18\x0b \x01(\x0b\x32,.CHIDMessageToRemote.DeviceStartInputReportsH\x00\x12R\n\x1a\x64\x65vice_request_full_report\x18\x0c \x01(\x0b\x32,.CHIDMessageToRemote.DeviceRequestFullReportH\x00\x12\x42\n\x11\x64\x65vice_disconnect\x18\r \x01(\x0b\x32%.CHIDMessageToRemote.DeviceDisconnectH\x00\x1a+\n\nDeviceOpen\x12\x1d\n\x04info\x18\x01 \x01(\x0b\x32\x0f.CHIDDeviceInfo\x1a\x1d\n\x0b\x44\x65viceClose\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a+\n\x0b\x44\x65viceWrite\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x1a@\n\nDeviceRead\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\r\x12\x12\n\ntimeout_ms\x18\x03 \x01(\x05\x1a\x37\n\x17\x44\x65viceSendFeatureReport\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x1aO\n\x16\x44\x65viceGetFeatureReport\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x15\n\rreport_number\x18\x02 \x01(\x0c\x12\x0e\n\x06length\x18\x03 \x01(\r\x1a\'\n\x15\x44\x65viceGetVendorString\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a(\n\x16\x44\x65viceGetProductString\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a-\n\x1b\x44\x65viceGetSerialNumberString\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a\x39\n\x17\x44\x65viceStartInputReports\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\r\x1a)\n\x17\x44\x65viceRequestFullReport\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a\x89\x01\n\x10\x44\x65viceDisconnect\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12W\n\x10\x64isconnectMethod\x18\x02 \x01(\x0e\x32\x1b.EHIDDeviceDisconnectMethod: k_EDeviceDisconnectMethodUnknown\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\t\n\x07\x63ommand\"\xcb\x05\n\x15\x43HIDMessageFromRemote\x12\x45\n\x12update_device_list\x18\x01 \x01(\x0b\x32\'.CHIDMessageFromRemote.UpdateDeviceListH\x00\x12:\n\x08response\x18\x02 \x01(\x0b\x32&.CHIDMessageFromRemote.RequestResponseH\x00\x12<\n\x07reports\x18\x03 \x01(\x0b\x32).CHIDMessageFromRemote.DeviceInputReportsH\x00\x12:\n\x0c\x63lose_device\x18\x04 \x01(\x0b\x32\".CHIDMessageFromRemote.CloseDeviceH\x00\x12\x43\n\x11\x63lose_all_devices\x18\x05 \x01(\x0b\x32&.CHIDMessageFromRemote.CloseAllDevicesH\x00\x1a\x34\n\x10UpdateDeviceList\x12 \n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x0f.CHIDDeviceInfo\x1a\x43\n\x0fRequestResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\r\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x1a\xb7\x01\n\x12\x44\x65viceInputReports\x12S\n\x0e\x64\x65vice_reports\x18\x01 \x03(\x0b\x32;.CHIDMessageFromRemote.DeviceInputReports.DeviceInputReport\x1aL\n\x11\x44\x65viceInputReport\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x12\'\n\x07reports\x18\x02 \x03(\x0b\x32\x16.CHIDDeviceInputReport\x1a\x1d\n\x0b\x43loseDevice\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\r\x1a\x11\n\x0f\x43loseAllDevicesB\t\n\x07\x63ommand*g\n\x12\x45HIDDeviceLocation\x12\x1a\n\x16k_EDeviceLocationLocal\x10\x00\x12\x1b\n\x17k_EDeviceLocationRemote\x10\x02\x12\x18\n\x14k_EDeviceLocationAny\x10\x03*\xc1\x01\n\x1a\x45HIDDeviceDisconnectMethod\x12$\n k_EDeviceDisconnectMethodUnknown\x10\x00\x12&\n\"k_EDeviceDisconnectMethodBluetooth\x10\x01\x12*\n&k_EDeviceDisconnectMethodFeatureReport\x10\x02\x12)\n%k_EDeviceDisconnectMethodOutputReport\x10\x03\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_hiddevices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EHIDDEVICELOCATION._serialized_start=3103
  _EHIDDEVICELOCATION._serialized_end=3206
  _EHIDDEVICEDISCONNECTMETHOD._serialized_start=3209
  _EHIDDEVICEDISCONNECTMETHOD._serialized_end=3402
  _CHIDDEVICEINFO._serialized_start=35
  _CHIDDEVICEINFO._serialized_end=625
  _CHIDDEVICEINPUTREPORT._serialized_start=627
  _CHIDDEVICEINPUTREPORT._serialized_end=746
  _CHIDMESSAGETOREMOTE._serialized_start=749
  _CHIDMESSAGETOREMOTE._serialized_end=2383
  _CHIDMESSAGETOREMOTE_DEVICEOPEN._serialized_start=1677
  _CHIDMESSAGETOREMOTE_DEVICEOPEN._serialized_end=1720
  _CHIDMESSAGETOREMOTE_DEVICECLOSE._serialized_start=1722
  _CHIDMESSAGETOREMOTE_DEVICECLOSE._serialized_end=1751
  _CHIDMESSAGETOREMOTE_DEVICEWRITE._serialized_start=1753
  _CHIDMESSAGETOREMOTE_DEVICEWRITE._serialized_end=1796
  _CHIDMESSAGETOREMOTE_DEVICEREAD._serialized_start=1798
  _CHIDMESSAGETOREMOTE_DEVICEREAD._serialized_end=1862
  _CHIDMESSAGETOREMOTE_DEVICESENDFEATUREREPORT._serialized_start=1864
  _CHIDMESSAGETOREMOTE_DEVICESENDFEATUREREPORT._serialized_end=1919
  _CHIDMESSAGETOREMOTE_DEVICEGETFEATUREREPORT._serialized_start=1921
  _CHIDMESSAGETOREMOTE_DEVICEGETFEATUREREPORT._serialized_end=2000
  _CHIDMESSAGETOREMOTE_DEVICEGETVENDORSTRING._serialized_start=2002
  _CHIDMESSAGETOREMOTE_DEVICEGETVENDORSTRING._serialized_end=2041
  _CHIDMESSAGETOREMOTE_DEVICEGETPRODUCTSTRING._serialized_start=2043
  _CHIDMESSAGETOREMOTE_DEVICEGETPRODUCTSTRING._serialized_end=2083
  _CHIDMESSAGETOREMOTE_DEVICEGETSERIALNUMBERSTRING._serialized_start=2085
  _CHIDMESSAGETOREMOTE_DEVICEGETSERIALNUMBERSTRING._serialized_end=2130
  _CHIDMESSAGETOREMOTE_DEVICESTARTINPUTREPORTS._serialized_start=2132
  _CHIDMESSAGETOREMOTE_DEVICESTARTINPUTREPORTS._serialized_end=2189
  _CHIDMESSAGETOREMOTE_DEVICEREQUESTFULLREPORT._serialized_start=2191
  _CHIDMESSAGETOREMOTE_DEVICEREQUESTFULLREPORT._serialized_end=2232
  _CHIDMESSAGETOREMOTE_DEVICEDISCONNECT._serialized_start=2235
  _CHIDMESSAGETOREMOTE_DEVICEDISCONNECT._serialized_end=2372
  _CHIDMESSAGEFROMREMOTE._serialized_start=2386
  _CHIDMESSAGEFROMREMOTE._serialized_end=3101
  _CHIDMESSAGEFROMREMOTE_UPDATEDEVICELIST._serialized_start=2733
  _CHIDMESSAGEFROMREMOTE_UPDATEDEVICELIST._serialized_end=2785
  _CHIDMESSAGEFROMREMOTE_REQUESTRESPONSE._serialized_start=2787
  _CHIDMESSAGEFROMREMOTE_REQUESTRESPONSE._serialized_end=2854
  _CHIDMESSAGEFROMREMOTE_DEVICEINPUTREPORTS._serialized_start=2857
  _CHIDMESSAGEFROMREMOTE_DEVICEINPUTREPORTS._serialized_end=3040
  _CHIDMESSAGEFROMREMOTE_DEVICEINPUTREPORTS_DEVICEINPUTREPORT._serialized_start=2964
  _CHIDMESSAGEFROMREMOTE_DEVICEINPUTREPORTS_DEVICEINPUTREPORT._serialized_end=3040
  _CHIDMESSAGEFROMREMOTE_CLOSEDEVICE._serialized_start=3042
  _CHIDMESSAGEFROMREMOTE_CLOSEDEVICE._serialized_end=3071
  _CHIDMESSAGEFROMREMOTE_CLOSEALLDEVICES._serialized_start=3073
  _CHIDMESSAGEFROMREMOTE_CLOSEALLDEVICES._serialized_end=3090
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_physicalgoods.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steammessages_physicalgoods.proto\x1a steammessages_unified_base.proto\"`\n.CPhysicalGoods_RegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"1\n/CPhysicalGoods_RegisterSteamController_Response\"l\n:CPhysicalGoods_CompleteSteamControllerRegistration_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"=\n;CPhysicalGoods_CompleteSteamControllerRegistration_Response\"h\n6CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"k\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15registration_complete\x18\x02 \x01(\x08\"\x85\x01\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\x12J\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\"~\n8CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\"\x88\x02\n/CPhysicalGoods_SteamControllerSetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12Q\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"2\n0CPhysicalGoods_SteamControllerSetConfig_Response\"\xca\x01\n/CPhysicalGoods_SteamControllerGetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12\x13\n\x0b\x61ppidorname\x18\x04 \x01(\t\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x95\x01\n8CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x04 \x01(\t\"\x85\x01\n0CPhysicalGoods_SteamControllerGetConfig_Response\x12Q\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\"u\n0CPhysicalGoods_DeRegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\"3\n1CPhysicalGoods_DeRegisterSteamController_Response\"r\n-CPhysicalGoods_SetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x11\n\taccountid\x18\x03 \x01(\r\"0\n.CPhysicalGoods_SetPersonalizationFile_Response\"Y\n-CPhysicalGoods_GetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x11\n\taccountid\x18\x02 \x01(\r\"I\n.CPhysicalGoods_GetPersonalizationFile_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x32\xd7\x0c\n\rPhysicalGoods\x12\xd4\x01\n\x17RegisterSteamController\x12/.CPhysicalGoods_RegisterSteamController_Request\x1a\x30.CPhysicalGoods_RegisterSteamController_Response\"V\x82\xb5\x18RRecords a serial number and the calling user\'s account info for warranty purposes.\x12\xd3\x01\n#CompleteSteamControllerRegistration\x12;.CPhysicalGoods_CompleteSteamControllerRegistration_Request\x1a<.CPhysicalGoods_CompleteSteamControllerRegistration_Response\"1\x82\xb5\x18-Marks a controller\'s registration as complete\x12\xd7\x01\n#QueryAccountsRegisteredToController\x12\x37.CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x1a\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\"=\x82\xb5\x18\x39Sends back a list of accounts registered to a controller.\x12\xb8\x01\n SetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerSetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerSetConfig_Response\"/\x82\xb5\x18+Sets a desired controller config for an app\x12\xb8\x01\n GetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerGetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerGetConfig_Response\"/\x82\xb5\x18+Gets a desired controller config for an app\x12\xa1\x01\n\x19\x44\x65RegisterSteamController\x12\x31.CPhysicalGoods_DeRegisterSteamController_Request\x1a\x32.CPhysicalGoods_DeRegisterSteamController_Response\"\x1d\x82\xb5\x18\x19\x44\x65 registers a controller\x12\xb7\x01\n SetControllerPersonalizationFile\x12..CPhysicalGoods_SetPersonalizationFile_Request\x1a/.CPhysicalGoods_SetPersonalizationFile_Response\"2\x82\xb5\x18.Stores the file ID of the personalization file\x12\xb5\x01\n GetControllerPersonalizationFile\x12..CPhysicalGoods_GetPersonalizationFile_Request\x1a/.CPhysicalGoods_GetPersonalizationFile_Response\"0\x82\xb5\x18,Gets the file ID of the personalization file\x1a\x33\x82\xb5\x18/A service to use physical goods related methodsB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_physicalgoods_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _PHYSICALGOODS._options = None
  _PHYSICALGOODS._serialized_options = b'\202\265\030/A service to use physical goods related methods'
  _PHYSICALGOODS.methods_by_name['RegisterSteamController']._options = None
  _PHYSICALGOODS.methods_by_name['RegisterSteamController']._serialized_options = b'\202\265\030RRecords a serial number and the calling user\'s account info for warranty purposes.'
  _PHYSICALGOODS.methods_by_name['CompleteSteamControllerRegistration']._options = None
  _PHYSICALGOODS.methods_by_name['CompleteSteamControllerRegistration']._serialized_options = b'\202\265\030-Marks a controller\'s registration as complete'
  _PHYSICALGOODS.methods_by_name['QueryAccountsRegisteredToController']._options = None
  _PHYSICALGOODS.methods_by_name['QueryAccountsRegisteredToController']._serialized_options = b'\202\265\0309Sends back a list of accounts registered to a controller.'
  _PHYSICALGOODS.methods_by_name['SetDesiredControllerConfigForApp']._options = None
  _PHYSICALGOODS.methods_by_name['SetDesiredControllerConfigForApp']._serialized_options = b'\202\265\030+Sets a desired controller config for an app'
  _PHYSICALGOODS.methods_by_name['GetDesiredControllerConfigForApp']._options = None
  _PHYSICALGOODS.methods_by_name['GetDesiredControllerConfigForApp']._serialized_options = b'\202\265\030+Gets a desired controller config for an app'
  _PHYSICALGOODS.methods_by_name['DeRegisterSteamController']._options = None
  _PHYSICALGOODS.methods_by_name['DeRegisterSteamController']._serialized_options = b'\202\265\030\031De registers a controller'
  _PHYSICALGOODS.methods_by_name['SetControllerPersonalizationFile']._options = None
  _PHYSICALGOODS.methods_by_name['SetControllerPersonalizationFile']._serialized_options = b'\202\265\030.Stores the file ID of the personalization file'
  _PHYSICALGOODS.methods_by_name['GetControllerPersonalizationFile']._options = None
  _PHYSICALGOODS.methods_by_name['GetControllerPersonalizationFile']._serialized_options = b'\202\265\030,Gets the file ID of the personalization file'
  _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST._serialized_start=71
  _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST._serialized_end=167
  _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE._serialized_start=169
  _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE._serialized_end=218
  _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST._serialized_start=220
  _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST._serialized_end=328
  _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE._serialized_start=330
  _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE._serialized_end=391
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST._serialized_start=393
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST._serialized_end=497
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS._serialized_start=499
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS._serialized_end=606
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE._serialized_start=609
  _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE._serialized_end=742
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG._serialized_start=744
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG._serialized_end=870
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST._serialized_start=873
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST._serialized_end=1137
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE._serialized_start=1139
  _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE._serialized_end=1189
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST._serialized_start=1192
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST._serialized_end=1394
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG._serialized_start=1397
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG._serialized_end=1546
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE._serialized_start=1549
  _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE._serialized_end=1682
  _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST._serialized_start=1684
  _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST._serialized_end=1801
  _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE._serialized_start=1803
  _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE._serialized_end=1854
  _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST._serialized_start=1856
  _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST._serialized_end=1970
  _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE._serialized_start=1972
  _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE._serialized_end=2020
  _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST._serialized_start=2022
  _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST._serialized_end=2111
  _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE._serialized_start=2113
  _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE._serialized_end=2186
  _PHYSICALGOODS._serialized_start=2189
  _PHYSICALGOODS._serialized_end=3812
_builder.BuildServices(DESCRIPTOR, 'steammessages_physicalgoods_pb2', globals())
# @@protoc_insertion_point(module_scope)



import struct
import logging

import ssl
import gevent
import certifi
from wsproto import WSConnection, events as wsevents
from wsproto.connection import ConnectionType, ConnectionState
from gevent import socket
from gevent import queue
from gevent import event
from gevent.select import select as gselect

logger = logging.getLogger("Connection")


class Connection(object):
    def __init__(self):
        self.socket = None
        self.connected = False
        self.server_addr = None

        self._reader = None
        self._writer = None
        self._readbuf = b''
        self.send_queue = queue.Queue()
        self.recv_queue = queue.Queue()

        self.event_connected = event.Event()

    @property
    def local_address(self):
        return self.socket.getsockname()[0]

    def connect(self, server_addr):
        self._new_socket()

        logger.debug("Attempting connection to %s", str(server_addr))

        try:
            self._connect(server_addr)
        except socket.error:
            return False

        self.server_addr = server_addr
        self.recv_queue.queue.clear()

        self._reader = gevent.spawn(self._reader_loop)
        self._writer = gevent.spawn(self._writer_loop)

        self.event_connected.wait(timeout=10)

        logger.debug("Connected.")
        self.event_connected.set()
        return True

    def disconnect(self):
        if not self.event_connected.is_set():
            return
        self.event_connected.clear()

        self.server_addr = None

        if self._reader:
            self._reader.kill(block=False)
            self._reader = None
        if self._writer:
            self._writer.kill(block=False)
            self._writer = None

        self._readbuf = b''
        self.send_queue.queue.clear()
        self.recv_queue.queue.clear()
        self.recv_queue.put(StopIteration)

        self.socket.close()

        logger.debug("Disconnected.")

    def __iter__(self):
        return self.recv_queue

    def put_message(self, message):
        self.send_queue.put(message)

    def _new_socket(self):
        raise TypeError("{}: _new_socket is unimplemented".format(self.__class__.__name__))

    def _connect(self, server_addr):
        raise TypeError("{}: _connect is unimplemented".format(self.__class__.__name__))
    
    def _reader_loop(self):
        raise TypeError("{}: _reader_loop is unimplemented".format(self.__class__.__name__))

    def _writer_loop(self):
        raise TypeError("{}: _writer_loop is unimplemented".format(self.__class__.__name__))


class TCPConnection(Connection):
    MAGIC = b'VT01'
    FMT = '<I4s'
    FMT_SIZE = struct.calcsize(FMT)
    
    def _new_socket(self):
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

    def _connect(self, server_addr):
        self.socket.connect(server_addr)

    def _read_data(self):
        try:
            return self.socket.recv(16384)
        except socket.error:
            return ''

    def _write_data(self, data):
        self.socket.sendall(data)
        
    def _writer_loop(self):
        while True:
            message = self.send_queue.get()
            packet = struct.pack(TCPConnection.FMT, len(message), TCPConnection.MAGIC) + message
            try:
                self._write_data(packet)
            except:
                logger.debug("TCPConnection error (writer).")
                self.disconnect()
                return

    def _reader_loop(self):
        while True:
            rlist, _, _ = gselect([self.socket], [], [])

            if self.socket in rlist:
                data = self._read_data()

                if not data:
                    logger.debug("Connection error (reader).")
                    self.disconnect()
                    return

                self._readbuf += data
                self._read_packets()

    def _read_packets(self):
        header_size = TCPConnection.FMT_SIZE
        buf = self._readbuf

        while len(buf) > header_size:
            message_length, magic = struct.unpack_from(TCPConnection.FMT, buf)

            if magic != TCPConnection.MAGIC:
                logger.debug("invalid magic, got %s" % repr(magic))
                self.disconnect()
                return

            packet_length = header_size + message_length

            if len(buf) < packet_length:
                return

            message = buf[header_size:packet_length]
            buf = buf[packet_length:]

            self.recv_queue.put(message)

        self._readbuf = buf


class UDPConnection(Connection):
    def _new_socket(self):
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)

    def _connect(self, server_addr):
        pass

    def _read_data(self):
        pass

    def _write_data(self, data):
        pass


class WebSocketConnection(Connection):
    def __init__(self):
        super(WebSocketConnection, self).__init__()
        self.ws = WSConnection(ConnectionType.CLIENT)
        self.ssl_ctx = ssl.create_default_context(cafile=certifi.where())
        self.event_wsdisconnected = event.Event()

    def _new_socket(self):
        self.raw_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

    def _connect(self, server_addr):

        host, port = server_addr
        
        for res in socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM):
            try:
                # tcp socket
                _, _, _, _, sa = res
                self.raw_socket.connect(sa)
                self.socket = self.ssl_ctx.wrap_socket(self.raw_socket, server_hostname=host)
                # websocket
                ws_host = ':'.join(map(str,server_addr))
                ws_send = self.ws.send(wsevents.Request(host=ws_host, target="/cmsocket/"))
                self.socket.sendall(ws_send)
                return
            except socket.error:
                if self.socket is not None:
                    self.socket.close()
    
    def _writer_loop(self):
        while True:
            message = self.send_queue.get()
            try:
                logger.debug("sending message of length {}".format(len(message)))
                self.socket.sendall(self.ws.send(wsevents.Message(data=message)))
            except:
                logger.debug("Connection error (writer).")
                self.disconnect()
                return
    
    def _reader_loop(self):
        while True:
            rlist, _, _ = gselect([self.socket], [], [])

            if self.socket in rlist:

                try:
                    data = self.socket.recv(16384)
                except socket.error:
                    data = ''

                if not data:
                    logger.debug("Connection error (reader).")
                    # A receive of zero bytes indicates the TCP socket has been closed. We
                    # need to pass None to wsproto to update its internal state.
                    logger.debug("Received 0 bytes (connection closed)")
                    self.ws.receive_data(None)
                    # now disconnect
                    self.disconnect()
                    return
                
                logger.debug("Received {} bytes".format(len(data)))
                self.ws.receive_data(data)
                self._handle_events()
    
    def _handle_events(self):
        for event in self.ws.events():
            if isinstance(event, wsevents.AcceptConnection):
                logger.debug("WebSocket negotiation complete. Connected.")
                self.event_connected.set()
            elif isinstance(event, wsevents.RejectConnection):
                logger.debug("WebSocket connection was rejected. That's probably not good.")
            elif isinstance(event, wsevents.TextMessage):
               logger.debug("Received websocket text message of length: {}".format(len(event.data)))
            elif isinstance(event, wsevents.BytesMessage):
                logger.debug("Received websocket bytes message of length: {}".format(len(event.data)))
                self.recv_queue.put(event.data)
            elif isinstance(event, wsevents.Pong):
                logger.debug("Received pong: {}".format(repr(event.payload)))
            elif isinstance(event, wsevents.CloseConnection):
                logger.debug('Connection closed: code={} reason={}'.format(
                    event.code, event.reason
                ))
                if self.ws.state == ConnectionState.REMOTE_CLOSING:
                    self.socket.send(self.ws.send(event.response()))
                self.event_wsdisconnected.set()
            else:
                raise TypeError("Do not know how to handle event: {}".format((event)))

    def disconnect(self):
        self.event_wsdisconnected.clear()
        
        # WebSocket closing handshake
        if self.ws.state == ConnectionState.OPEN:
            logger.debug("Disconnect called. Sending CloseConnection message.")
            self.socket.sendall(self.ws.send(wsevents.CloseConnection(code=1000, reason="sample reason")))
            self.socket.shutdown(socket.SHUT_WR)
            # wait for notification from _reader_loop that the closing response was received
            self.event_wsdisconnected.wait()

        super(WebSocketConnection, self).disconnect()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_storagedevicemanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(webuimessages_storagedevicemanager.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"2\n0CStorageDeviceManager_IsServiceAvailable_Request\"I\n1CStorageDeviceManager_IsServiceAvailable_Response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\"\xe9\x02\n\x1a\x43StorageDeviceManagerDrive\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06vendor\x18\x03 \x01(\t\x12\x0e\n\x06serial\x18\x04 \x01(\t\x12\x14\n\x0cis_ejectable\x18\x05 \x01(\x08\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12M\n\nmedia_type\x18\x07 \x01(\x0e\x32\x17.EStorageDriveMediaType: k_EStorageDriveMediaType_Invalid\x12\x16\n\x0eis_unformatted\x18\x08 \x01(\x08\x12H\n\x0b\x61\x64opt_stage\x18\t \x01(\x0e\x32\x14.EStorageFormatStage:\x1dk_EStorageFormatStage_Invalid\x12\x16\n\x0eis_formattable\x18\n \x01(\x08\x12\x1a\n\x12is_media_available\x18\x0b \x01(\x08\"\xce\x03\n CStorageDeviceManagerBlockDevice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x13\n\x08\x64rive_id\x18\x02 \x01(\r:\x01\x30\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x15\n\rfriendly_path\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12\x16\n\x0eis_formattable\x18\x07 \x01(\x08\x12\x14\n\x0cis_read_only\x18\x08 \x01(\x08\x12\x16\n\x0eis_root_device\x18\t \x01(\x08\x12S\n\x0c\x63ontent_type\x18\n \x01(\x0e\x32\x19.EStorageBlockContentType:\"k_EStorageBlockContentType_Invalid\x12\\\n\x0f\x66ilesystem_type\x18\x0b \x01(\x0e\x32\x1c.EStorageBlockFileSystemType:%k_EStorageBlockFileSystemType_Invalid\x12\x13\n\x0bmount_paths\x18\x0c \x03(\t\x12\x15\n\ris_unmounting\x18\r \x01(\x08\x12\x19\n\x11has_steam_library\x18\x0e \x01(\x08\"\xf1\x01\n\x1a\x43StorageDeviceManagerState\x12+\n\x06\x64rives\x18\x01 \x03(\x0b\x32\x1b.CStorageDeviceManagerDrive\x12\x38\n\rblock_devices\x18\x02 \x03(\x0b\x32!.CStorageDeviceManagerBlockDevice\x12\x1c\n\x14is_unmount_supported\x18\x03 \x01(\x08\x12\x19\n\x11is_trim_supported\x18\x04 \x01(\x08\x12\x17\n\x0fis_trim_running\x18\x05 \x01(\x08\x12\x1a\n\x12is_adopt_supported\x18\x06 \x01(\x08\"(\n&CStorageDeviceManager_GetState_Request\"U\n\'CStorageDeviceManager_GetState_Response\x12*\n\x05state\x18\x01 \x01(\x0b\x32\x1b.CStorageDeviceManagerState\"1\n/CStorageDeviceManager_StateChanged_Notification\"7\n#CStorageDeviceManager_Eject_Request\x12\x10\n\x08\x64rive_id\x18\x01 \x01(\r\"&\n$CStorageDeviceManager_Eject_Response\"X\n#CStorageDeviceManager_Adopt_Request\x12\x10\n\x08\x64rive_id\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\x12\x10\n\x08validate\x18\x03 \x01(\x08\"&\n$CStorageDeviceManager_Adopt_Response\"?\n$CStorageDeviceManager_Format_Request\x12\x17\n\x0f\x62lock_device_id\x18\x01 \x01(\r\"\'\n%CStorageDeviceManager_Format_Response\"@\n%CStorageDeviceManager_Unmount_Request\x12\x17\n\x0f\x62lock_device_id\x18\x01 \x01(\r\"(\n&CStorageDeviceManager_Unmount_Response\"\'\n%CStorageDeviceManager_TrimAll_Request\"(\n&CStorageDeviceManager_TrimAll_Response2\x8f\x06\n\x14StorageDeviceManager\x12{\n\x12IsServiceAvailable\x12\x31.CStorageDeviceManager_IsServiceAvailable_Request\x1a\x32.CStorageDeviceManager_IsServiceAvailable_Response\x12]\n\x08GetState\x12\'.CStorageDeviceManager_GetState_Request\x1a(.CStorageDeviceManager_GetState_Response\x12X\n\x12NotifyStateChanged\x12\x30.CStorageDeviceManager_StateChanged_Notification\x1a\x10.WebUINoResponse\x12T\n\x05\x41\x64opt\x12$.CStorageDeviceManager_Adopt_Request\x1a%.CStorageDeviceManager_Adopt_Response\x12T\n\x05\x45ject\x12$.CStorageDeviceManager_Eject_Request\x1a%.CStorageDeviceManager_Eject_Response\x12W\n\x06\x46ormat\x12%.CStorageDeviceManager_Format_Request\x1a&.CStorageDeviceManager_Format_Response\x12Z\n\x07Unmount\x12&.CStorageDeviceManager_Unmount_Request\x1a\'.CStorageDeviceManager_Unmount_Response\x12Z\n\x07TrimAll\x12&.CStorageDeviceManager_TrimAll_Request\x1a\'.CStorageDeviceManager_TrimAll_Response\x1a\x04\x80\x97\"\x01\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_storagedevicemanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _STORAGEDEVICEMANAGER._options = None
  _STORAGEDEVICEMANAGER._serialized_options = b'\200\227\"\001'
  _CSTORAGEDEVICEMANAGER_ISSERVICEAVAILABLE_REQUEST._serialized_start=109
  _CSTORAGEDEVICEMANAGER_ISSERVICEAVAILABLE_REQUEST._serialized_end=159
  _CSTORAGEDEVICEMANAGER_ISSERVICEAVAILABLE_RESPONSE._serialized_start=161
  _CSTORAGEDEVICEMANAGER_ISSERVICEAVAILABLE_RESPONSE._serialized_end=234
  _CSTORAGEDEVICEMANAGERDRIVE._serialized_start=237
  _CSTORAGEDEVICEMANAGERDRIVE._serialized_end=598
  _CSTORAGEDEVICEMANAGERBLOCKDEVICE._serialized_start=601
  _CSTORAGEDEVICEMANAGERBLOCKDEVICE._serialized_end=1063
  _CSTORAGEDEVICEMANAGERSTATE._serialized_start=1066
  _CSTORAGEDEVICEMANAGERSTATE._serialized_end=1307
  _CSTORAGEDEVICEMANAGER_GETSTATE_REQUEST._serialized_start=1309
  _CSTORAGEDEVICEMANAGER_GETSTATE_REQUEST._serialized_end=1349
  _CSTORAGEDEVICEMANAGER_GETSTATE_RESPONSE._serialized_start=1351
  _CSTORAGEDEVICEMANAGER_GETSTATE_RESPONSE._serialized_end=1436
  _CSTORAGEDEVICEMANAGER_STATECHANGED_NOTIFICATION._serialized_start=1438
  _CSTORAGEDEVICEMANAGER_STATECHANGED_NOTIFICATION._serialized_end=1487
  _CSTORAGEDEVICEMANAGER_EJECT_REQUEST._serialized_start=1489
  _CSTORAGEDEVICEMANAGER_EJECT_REQUEST._serialized_end=1544
  _CSTORAGEDEVICEMANAGER_EJECT_RESPONSE._serialized_start=1546
  _CSTORAGEDEVICEMANAGER_EJECT_RESPONSE._serialized_end=1584
  _CSTORAGEDEVICEMANAGER_ADOPT_REQUEST._serialized_start=1586
  _CSTORAGEDEVICEMANAGER_ADOPT_REQUEST._serialized_end=1674
  _CSTORAGEDEVICEMANAGER_ADOPT_RESPONSE._serialized_start=1676
  _CSTORAGEDEVICEMANAGER_ADOPT_RESPONSE._serialized_end=1714
  _CSTORAGEDEVICEMANAGER_FORMAT_REQUEST._serialized_start=1716
  _CSTORAGEDEVICEMANAGER_FORMAT_REQUEST._serialized_end=1779
  _CSTORAGEDEVICEMANAGER_FORMAT_RESPONSE._serialized_start=1781
  _CSTORAGEDEVICEMANAGER_FORMAT_RESPONSE._serialized_end=1820
  _CSTORAGEDEVICEMANAGER_UNMOUNT_REQUEST._serialized_start=1822
  _CSTORAGEDEVICEMANAGER_UNMOUNT_REQUEST._serialized_end=1886
  _CSTORAGEDEVICEMANAGER_UNMOUNT_RESPONSE._serialized_start=1888
  _CSTORAGEDEVICEMANAGER_UNMOUNT_RESPONSE._serialized_end=1928
  _CSTORAGEDEVICEMANAGER_TRIMALL_REQUEST._serialized_start=1930
  _CSTORAGEDEVICEMANAGER_TRIMALL_REQUEST._serialized_end=1969
  _CSTORAGEDEVICEMANAGER_TRIMALL_RESPONSE._serialized_start=1971
  _CSTORAGEDEVICEMANAGER_TRIMALL_RESPONSE._serialized_end=2011
  _STORAGEDEVICEMANAGER._serialized_start=2014
  _STORAGEDEVICEMANAGER._serialized_end=2797
_builder.BuildServices(DESCRIPTOR, 'webuimessages_storagedevicemanager_pb2', globals())
# @@protoc_insertion_point(module_scope)
